# Aiko Services example: XGO-Mini 2 quadruped robot dog

Note: *Only the XGO-Mini 2 is supported, not the original XGO-Mini robot*

[LuWu Dynamics: XGO-Mini 2 Wiki](https://www.yuque.com/luwudynamics/en)

[KickStarter campaign:  Raspberry Pi Robotic Dog with An Arm](https://www.kickstarter.com/projects/xgorobot/xgo-2-worlds-first-raspberry-pi-robotic-dog-with-an-arm)

XGO-Mini 2 is a small robot dog created by Luwu Intelligence Technology.
It has 3 high-quality servo motors per leg and a 3 DoF arm with a gripper.
The main CPU is a Raspberry Pi 4 compute module (CM4) with a camera and screen.
An ESP32 manages the servo motors and an IMU.
